Module error

Module error 

Error handling module.

This module exports types related to error handling, such as the FlutterbugError, a catch-all error type, and the X11Error, which holds data derived from the XErrorEvent type.

Enums

DroppableObject
Objects that can be dropped with a reference.
FlutterbugError
An error that occurred during normal operation of Flutterbug.